@@ -13,9 +13,12 @@ class PredictorPipeline(ModelPipeline):
     The (user,item) prediction will be computed and for each pair that is present in the test set.
     """
 
-    def test_model_ratings(self, model, output_path, batch_size, **kwargs):
+    def test_model_ratings(self, model, output_path, batch_size, is_running, **kwargs):
         start_index = 0
         while start_index < len(self.test_set):
+            if not is_running():
+                return
+
             user_batch = self.test_set[start_index : start_index + batch_size]
             predictions = model.predict_batch(user_batch)
             predictions.to_csv(output_path, mode='a', sep='\t', header=False, index=False)
